from setuptools import setup

setup(
install_requires=[
    'numpy>=1.22.4',
    'pandas>=1.5.3',
    'matplotlib>=3.7.1',
    'scikit-learn>=1.2.2',
    'seaborn>=0.12.2',
    'ngt>=2.0.4',
    'anytree>=2.8.0',
    'treelib>=1.6.1',
    ]

)